matrix-floppy 💾
===============

Save your Matrix history.

Motivation
----------

My motivation for writing this application is to give me an offline browseable
and searchable archive of my Matrix chat history. This can be handy if my
homeserver is down, or if I want to move homeserver, or just to be able to
search encrypted chat history without needing to use Element Desktop.

Features
--------

Media types:

* [x] Unencrypted messages
* [x] Encrypted messages
* [ ] Images
* [ ] Videos
* [ ] Reactions

Operation modes:

* [x] Batch
* [ ] Real-time client

Output formats:

* [x] HTML
* [ ] Plain-text
* [ ] JSON

Installation
------------

I've never used it before, but I'm using pipenv for this project. I'll update
this section once I've figured it out myself.

License
-------

Copyright (C) Iain R. Learmonth 2021. See `COPYING` for permissions.
